@@ -1,3 +1,7 @@
+# SPDX-FileCopyrightText: 2020 Mintlab B.V.
+#
+# SPDX-License-Identifier: EUPL-1.2
+
 import datetime
 from minty.entity import Entity, EntityCollection
 from pyramid.renderers import JSON
@@ -69,22 +73,43 @@ class jsonapi(JSON):
         for relationshipkey in obj.entity_relationships:
             relationship = getattr(obj, relationshipkey)
             if relationship is not None:
-                relationshipdata = relationship.dict()
+                list_of_relationships = False
+                is_list = None
+                if isinstance(relationship, list):
+                    list_of_relationships = relationship
+                    is_list = True
+                else:
+                    list_of_relationships = [relationship]
 
-                metadata = {}
-                if relationshipdata["entity_meta_summary"] is not None:
-                    metadata["meta"] = {
-                        "summary": relationshipdata["entity_meta_summary"]
+                for relationshipcontent in list_of_relationships:
+                    relationshipdata = relationshipcontent.dict()
+
+                    metadata = {}
+                    if relationshipdata["entity_meta_summary"] is not None:
+                        metadata["meta"] = {
+                            "summary": relationshipdata["entity_meta_summary"]
+                        }
+
+                    relationship_response = {
+                        "data": {
+                            "type": relationshipdata["entity_type"],
+                            "id": relationshipdata["entity_id"],
+                        },
+                        **metadata,
+                        **self.__links_for_entity(relationshipcontent),
                     }
 
-                object_relationships[relationshipkey] = {
-                    "data": {
-                        "type": relationshipdata["entity_type"],
-                        "id": relationshipdata["entity_id"],
-                    },
-                    **metadata,
-                    **self.__links_for_entity(relationship),
-                }
+                    if not is_list:
+                        object_relationships[
+                            relationshipkey
+                        ] = relationship_response
+                    else:
+                        if relationshipkey not in object_relationships:
+                            object_relationships[relationshipkey] = []
+
+                        object_relationships[relationshipkey].append(
+                            relationship_response
+                        )
 
             del object_attributes[relationshipkey]
 
